<?php 
    // Determine if the form was submitted recently
    if (!isset($_POST['formSubmitted']) || 
        !htmlspecialchars($_POST['formSubmitted'])=='TRUE'){
        // Require the login since we are not submitting the form
        require_once('php_only_scripts/protector.php');
    }
    
    // continue the session
    session_start();
    
    // Add includes to PHP files that I will need to access
    require_once 'php_only_scripts/database.php';
    require_once 'php_only_scripts/presentation.php';
    include 'php_only_scripts/benefits_presentation.php';

    // Init some variables
    $userRow=null;
    $benefitsUserAssocRow=null;
    $benefitsUserID=-1;

    // Assume NOT gtg
    $gtg = false;
    
    // Create and Setup the database
    $db = new Database();
    $db->setupTmsDB();

    // Attempt to log in with this user
    $currentUser = $db->getLoggedInSessionUser(session_id());
    
    // If there is only one result for a username/password combo, then they are good to go.
    if ($currentUser == null){
        exit;
    }
    elseif (mysqli_num_rows($currentUser)==1){
        // Attempt to get the user row
        $userRow = $currentUser->fetch_assoc();

        // Determine if a user ID sent in the URL
        if (isset($_GET['benefitsUserID']) ){
            // Hold onto the benefits user ID to be used
            $benefitsUserID = $_GET['benefitsUserID'];
        }
        else {
            // Determine if a user ID sent in a post
            if (isset($_POST['UserID']) ){
                // Hold onto the Timecard user ID to be used
                $benefitsUserID = $_POST['UserID'];
            }
            else {
                // Hold onto the Timecard user ID to be used
                $benefitsUserID = $userRow['UserID'];
            }
        }

        // Create a query to to get bonus user information on the passed in bonus user
        $sql = 'SELECT * FROM users u ' .
               'WHERE u.UserID=' . $benefitsUserID . ';';

        // Attempt to get the bonus user row
        $bonusUserRow = $db->queryDB($sql, $userRow, "benefits Form occurance 1");

        // Attempt to get the bonus user row
        $benefitsUserAssocRow = $bonusUserRow->fetch_assoc();
 
        // Determine if this user is allowed here or not
        if ($userRow["AccountStatus"]=='ACTIVE' &&
            $userRow["SUEmployee"]==1 && 
            $userRow["UserLevel"]!='TIMECARD ONLY' &&
            ($userRow["UserLevel"]=='SU' ||
             ($userRow["UserLevel"]=='EXECUTIVE' && $userRow["CompanyID"]==$benefitsUserAssocRow["CompanyID"]) ||
             ($userRow["UserID"]==$benefitsUserAssocRow["UserID"]))){
            // Set the good to go until they log out
            $gtg = true;
        
            // Determine if the form was submitted recently
            if (isset($_POST['formSubmitted']) && 
                htmlspecialchars($_POST['formSubmitted'])=='TRUE'){
                // Determine if this user can even modify
                if (!$userRow["CanModify"]){
                    // Let them know they cannot modify
                    echo "<script type=\"text/javascript\">window.alert('Your profile does not allow you to modify.\nContact a higher level to request this privilege.');</script>"; 

                    // redirect to the tasks page
                    echo ('<script>window.location = "tasks.php";</script>');
                }
                else {
                    // Set the local variables from what was posted for the timecard table
                    $userID = $benefitsUserID;
                    $hoursWorkedThisYear = htmlspecialchars($_POST['hoursWorkedThisYear'], ENT_QUOTES, 'UTF-8');
                    $ptoHoursAccruedThisYear = htmlspecialchars($_POST['ptoHoursAccruedThisYear'], ENT_QUOTES, 'UTF-8');
                    $ptoBalance = htmlspecialchars($_POST['ptoBalance'], ENT_QUOTES, 'UTF-8');
                    $lastPayDateUpdated = htmlspecialchars($_POST['lastPayDate'], ENT_QUOTES, 'UTF-8');
                    $isOnTrialPeriod = (isset($_POST['trialPeriod'])?1:0);

                    // Let's create the update query off of what we have
                    $sql='UPDATE employeebenefits SET ';
                    $sql= $sql . 'UserID=' . $userID;
                    $sql= $sql . ', TrialPeriod=' . $isOnTrialPeriod;
                    if ($hoursWorkedThisYear!=null) {$sql = $sql . ', HoursWorkedThisYear=' . $hoursWorkedThisYear;}
                    if ($ptoHoursAccruedThisYear!=null) {$sql = $sql . ', PTOHoursAccruedThisYear=' . $ptoHoursAccruedThisYear;}
                    if ($ptoBalance!=null) {$sql = $sql . ', PTOBalance=' . $ptoBalance;}
                    if ($lastPayDateUpdated!=null) {$sql = $sql . ', LastPayDateUpdated="' . $lastPayDateUpdated . '"';}
                    $sql=$sql .' WHERE UserID=' . $userID . ';';
//echo '<script>alert("' . addslashes($sql) . '");</script>';

                    // Attempt to run the query and evaluate the response
                    if (!$db->queryDB($sql, $userRow, "benefits Form occurance 2")){
                        echo '<script>alert("Company was NOT updated in the database. Please check the data and try again.");</script>';
                        // TODO: How do I want to display a failure to the user?
                    }
                    
                    // Change the form back to NOT being submitted
                    $_SESSION['formSubmitted']='FALSE';
                }
            }
            else {
                // Set the form submitted session variable to FALSE
                $_POST['formSubmitted']='FALSE';
            }
        }
        else {
            // redirect to the invalid access page
            echo ('<script>window.location = "invalid_access.php";</script>');

            exit;
        }
    }
?>
        
﻿<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

    <title>Task Management System - Financials</title>

    <meta name="keywords" content="GIS,data,testing,IT" />
    <meta name="description" content="EES Divisions." />

    <script language="JavaScript" src="scripts/gen_validatorv4.js" type="text/javascript"></script>
    <script src="./SpryAssets/SpryMenuBar.js" type="text/javascript"></script>
    <script src="./javascript/general.js" type="text/javascript"></script>

    <link rel="icon" href="images/ees_ico.ico"/> 
    <link href="./SpryAssets/SpryMenuBarHorizontal.css" rel="stylesheet" type="text/css" />
    <link href="./SpryAssets/SpryMenuBarVertical.css" rel="stylesheet" type="text/css" />
    <link rel = "stylesheet" type="text/css" href="./css/contentpage.css" >
</head>

<body class="thrColElsHdr">

<div id="container">
  
<!-- start of banner wrap --->

<div id="topContent">
  
<div>
   <div class="MenuBarHorizontal" id="navBar">  <ul id="TopNav" class="MenuBarHorizontal">

    <script type="text/javascript">
    <!--
    var MenuBar2 = new Spry.Widget.MenuBar("TopNav", {imgDown:"./SpryAssets/SpryMenuBarDownHover.gif", imgRight:"./SpryAssets/SpryMenuBarRightHover.gif"});
    //-->
    </script>

    </div>
  </div>
</div>
<!-- end of banner wrap --->

  <!-- end #header -->
  <br class="clearfloat" />
  <div id="sidebar1">
      <?php 
        // Determine if we are GTG
        if ($gtg){
          // Render the appropriate presentation for the tasks sidebar
          getSidebar($userRow, 'financials');
        }
      ?>       
      <br class="clearfloat" />
  <!-- end #sidebar1 -->
  </div>
  
  <!-- start #mainContent -->
  <div id="mainContent">
    <div class="maintitle">Task Management System - Financials</div>
    <div class="breadcrumb"> <a href="../index.html"> Home </a> > <a href="tasks.php"> Task Management System </a> > <a href="financials.php"> Financials </a></div>

    <br>
        
    <?php
        // Determine if they are GTG
        if ($gtg){
            // Time to query for their bonuses
            echo getUserBenefits($db, $userRow, $benefitsUserAssocRow);
        }
        else {
            // Set the login failed to true
            $_SESSION['failedLogin']='TRUE';

            // Add a session variable that is this page URL
            $_SESSION['pageToGoTo']=$_SERVER['REQUEST_URI'];

            // redirect to the login page
            echo ('<script>window.location = ".";</script>');
        }
    ?>       
    
  <!-- end #mainContent -->
  
  <!-- This clearing element should immediately follow the #mainContent div in order to force the #container div to contain all child floats -->
  <br class="clearfloat" />
  
  <!-- start #footer --></div>
   <div id="footer">
    <p>© 2018 Evolve Engineering and Software. EES, Evolve Engineering and Software, EES Logo are registered marks of Evolve Engineering and Software.</p>
  <!-- end #footer -->
   </div>
<!-- end #container -->
</div>

</body>

</html>